package com.bwie.auth.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.bwie.auth.feign.SystemRemoteService;
import com.bwie.auth.service.AuthService;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.constants.TokenConstants;
import com.bwie.common.domain.User;
import com.bwie.common.domain.response.JwtResponse;
import com.bwie.common.result.Result;
import com.bwie.common.utils.JwtUtils;
import com.bwie.common.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import java.util.LinkedHashMap;
import java.util.StringTokenizer;
import java.util.UUID;
import java.util.concurrent.TimeUnit;

/**
 * @Author：zhangchengzhi
 * @Package：com.bwie.auth.service.impl
 * @Project：test_day_13
 * @name：AuthService
 * @Date：2024/8/1 8:49
 */
@Service
public class AuthServiceImpl implements AuthService {

    @Autowired
    private StringRedisTemplate redisTemplate;
    @Autowired
    private SystemRemoteService systemRemoteService;


    @Override
    public Result login(User user) {

        if (StringUtils.isAnyBlank(user.getUserPwd(),user.getUserName())){
            return Result.error("手机号和密码不能为空");
        }

        Result<User> result = systemRemoteService.login(user.getUserName());

        User userlogin = result.getData();

        if (null==userlogin){
            return Result.error("用户名错误");
        }

        if (!userlogin.getUserPwd().equals(user.getUserPwd())){
            return Result.error("密码错误");
        }

LinkedHashMap<String, Object> claims = new LinkedHashMap<>();

 String userKey = UUID.randomUUID().toString().replace("-", "");

claims.put(JwtConstants.USER_KEY,userKey);

String token = JwtUtils.createToken(claims);

redisTemplate.opsForValue().set(TokenConstants.LOGIN_TOKEN_KEY+userKey, JSONObject.toJSONString(userlogin),30, TimeUnit.MINUTES);

        JwtResponse jwtResponse = new JwtResponse();

        jwtResponse.setToken(token);

        jwtResponse.setExpireTimeStr("30min");

        return Result.success(jwtResponse);
    }
}
